A seperate lme model is fited per omic in the pathway and the estimates are combined based on the indexes
of pairs to create initial values for the pairslapmeg function.
pairsetinval(index, fixed, random, subject, data)Indexes of pairs used for replacing the parameters in the jopint model
A two-sided linear formula object for specifying the
fixed-effects in the linear mixed model at the latent process level. Names
of omics in the pathway are separated by + on the left of ~ and the
covariates are separated by + on the right of the ~. For
identifiability purposes, the intercept should always be present in the model.
A one-sided formula for the random-effects in the
latent process mixed model and starts with the ~ sign. At least one random
effect should be included. Covariates with a random-effect are separated
by +.
name of the covariate representing the repeated measures structure such as subject IDs.
data frame containing the variables named in fixed, random,
grouping and subject.
A list of vectors, each including vector of initial values corresponding to pairs based on the index file. These vectors will be used as input for multlcmm function of each paired model.