A list is returned including:
callthe matched call
nfixNumber
of fixed effect terms in the model, excluding the mandatory intercept
nrandNumber of
random effect terms in the model
nsubjNumber of subjects in the sataset
nrepTable of repeated measures, and number of subjects with the specified number of repeated measures
tgroupTable of grouping, and number of subjects in each group
YnamesName of the
Omics in the pathway
slapconvStatus of convergence: For joint method(=1 if the convergence
criteria were satisfied, =2 if the maximum number of iterations was reached, =4 or 5 if a problem
occured during optimisation); for the pairwise method, proportion of successfully converged pairs
is reported
fixedformNames of Fixed effect terms
randformNames of random effect
terms
slapmethodThe method which is "joint" if the original slapmeg approach is adopted
and pairwise for the pairwise method
SLaP.parFitted values for
the parameters in the joint class mixed model in the first step
GlobaltestThe output
from Globaltest at the second step
EB_predEmpirical
bayes estimates for the random effects from the joint model