Learn R Programming

SlaPMEG (version 1.0.1)

plotslapmeg: Plot the estimated random effects from SLaPMEG seperated for the study groups

Description

This plot can provide a graphical insight into the source of effect (i.e. diffrential expression) in relevent pathway.

Usage

plotslapmeg(obj, ...)

Arguments

obj

An slapmeg object which is the output from slapmeg or pairslapmeg. Note that the fullreturn=TRUE) must have been used.

optional graphical parameters can be added with an + based on ggplot2 structure.

Value

returns NULL

References

Ebrahimpoor, Mitra, Pietro Spitali, Jelle J. Goeman, and Roula Tsonaka. "Pathway testing for longitudinal metabolomics." Statistics in Medicine (2021).

See Also

slapmeg, multslapmeg, pairslapmeg

Examples

Run this code
# NOT RUN {
# simulate data with 8 omics
testdata<-simslapmeg(nY=8, ntime=5, nsubj = 30, seed=123)
head(testdata)

#fit slapmeg to test for the differential expression of a pathway of size 5
fit<- slapmeg(Y1+Y2+Y6+Y7+Y8~time, ~1, grouping="group", subject="ID", data=testdata)

#Density plots for the estimated random effects
plotslapmeg(fit)

# }

Run the code above in your browser using DataLab