Learn R Programming

SlaPMEG (version 1.0.1)

print.slapmeg: Print objects from slapmeg

Description

Provides an overview of SLaPMEG approach through slapmeg and pairslapmeg objects.

Usage

# S3 method for slapmeg
print(x, ...)

Arguments

x

an object inheriting from class slapmeg

further arguments to be passed to or from other methods, which will be ignored in this function.

Value

Returns result summaries of SLAPMEG approach

See Also

slapmeg, pairslapmeg