Globaltest is used to test the association between phenotype variable and estimated random effects from step I.
slapGT(EBS, data_inf, rand_nam, Ynames, grouping, Emethod)Estimated random effects by either joint or pairwise approach
Dataframe with variables required for the test
Names of random effects defined in model
Name of omics in pathway
Name of the covariate representing the grouping by the phenotype
Estimation method for the random effects which is either joint or pairwise
A GT object containing globaltest results