slapmeg objectsProvides a table of sorted p-values for the output of multSLaPMEG approach within multslapmeg objects.
# S3 method for mslapmeg
summary(object, n = 5, ...)an object inheriting from classes multslapmeg
an integer indicating number of pathways to be printed the default is 5
further arguments to be passed to or from other methods, which will be ignored in this function.
'Returns the fixed effect estimates and random effects variances from the model in step 1 and the details of Globaltest along with p-value from step 2.