Learn R Programming

SlaPMEG (version 1.0.1)

summary.slapmeg: Summary of slapmeg objects

Description

Provides a summary of values estimated with SLaPMEG approach within slapmeg and pairslapmeg objects.

Usage

# S3 method for slapmeg
summary(object, ...)

Arguments

object

an object inheriting from classes slapmeg

further arguments to be passed to or from other methods, which will be ignored in this function.

Value

'Returns the fixed effect estimates and random effects variances from the model in step 1 and the details of Globaltest along with p-value from step 2.

See Also

slapmeg, pairslapmeg,